<?php namespace EscapeWork\Manager\Subscribers\Commands;

use EscapeWork\Manager\Subscribers\Export\MailChimpExporter;
use EscapeWork\Manager\Subscribers\Repositories\Subscriber\SubscriberRepository;
use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;

class MailChimpExportCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager-subscribers:mailchimp-export';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Exporta os contatos para o MailChimp.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(SubscriberRepository $subscriber)
    {
        parent::__construct();

        $this->subscriber = $subscriber;
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        try {
            $subscribers = $this->subscriber->getNewerSubscribers();

            $exporter = new MailChimpExporter();
            $exporter->export($subscribers);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }

        $this->info('Contatos exportados com sucesso!');
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments()
    {
        return array();
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return array();
    }

}
