<?php namespace EscapeWork\Manager\Subscribers\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Subscribers\Repositories\Subscriber\SubscriberRepository;
use EscapeWork\Manager\Services\Exporter\CSVExporter;
use View;
use Config;
use Input;
use Redirect;
use Response;
use Request;

class SubscribersController extends ManagerController
{

    public function __construct(SubscriberRepository $subscriber)
    {
        $this->subscriber = $subscriber;

        # filters
        $this->enableDefaultFilters('subscribers');
    }

    /**
     * Listando os banners
     */
    public function index()
    {
        $view              = View::make(Config::get('manager-subscribers::views.subscribers.index'));
        $view->subscribers = $this->subscriber->filterAndPaginate(Input::all());

        return $view;
    }

    public function create()
    {
        $this->subscriber->fill(Input::old());

        $view             = View::make(Config::get('manager-subscribers::views.subscribers.form'));
        $view->subscriber = $this->subscriber;
        $view->edit       = false;

        return $view;
    }

    public function store()
    {
        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            if (Request::ajax()) {
                return Response::json(array(
                    'errors'     => $this->subscriber->getValidationErrors()->toArray(),
                    'subscriber' => $this->subscriber->toArray(),
                ));
            } else {
                return Redirect::route('manager.subscribers.create')
                        ->withInput()
                        ->with('errors', $this->subscriber->getValidationErrors()->toArray());
            }
        }

        $this->subscriber->save();

        if (Request::ajax()) {
            return Response::json(array(
                'message'    => 'Cadastro realizado com sucesso',
                'subscriber' => $this->subscriber->toArray(),
            ));
        } else {
            return Redirect::route('manager.subscribers.index')
                    ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi inserido com sucesso!');
        }
    }

    public function edit($id)
    {
        $this->subscriber = $this->subscriber->findOrFail($id);
        $this->subscriber->fill(Input::old());

        $view             = View::make(Config::get('manager-subscribers::views.subscribers.form'));
        $view->subscriber = $this->subscriber;
        $view->edit       = true;

        return $view;
    }

    public function update($id)
    {
        $this->subscriber = $this->subscriber->findOrFail($id);
        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            return Redirect::route('manager.subscribers.create')
                    ->withInput()
                    ->with('errors', $this->subscriber->getValidationErrors()->toArray());
        }

        $this->subscriber->save();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi atualizado com sucesso!');
    }

    public function destroy($id)
    {
        $this->subscriber = $this->subscriber->findOrFail($id);
        $this->subscriber->delete();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi excluído com sucesso!');
    }

    /**
     * Exportando os contatos para CSV
     */
    public function export()
    {
        $subscribers = $this->subscriber->all();
        $exporter    = new CSVExporter();

        # header
        $exporter->writeLine(array(
            'ID', 'Nome', 'E-mail', 'Sexo', 'Data de Nascimento', 'Cidade', 'Estado', 'País', 'Data de cadastro', 'Data de atualização',
        ));

        foreach ($subscribers as $subscriber) {
            $exporter->writeLine($subscriber->toArray());
        }

        return $exporter->export(array('filename' => 'contatos-newsletter-'.date('Y-m-d')));
    }
}
