<?php namespace EscapeWork\Manager\Subscribers\Models;

use EscapeWork\LaravelHelpers\Eloquent;

class Subscriber extends Eloquent
{

    /**
     * Tabela
     */
    protected $table = 'subscribers';

    /**
     * Validation rules
     */
    public static $validationRules = array(
        'email' => array('required', 'email'),
    );

    /**
     * Validation messages
     */
    public static $validationMessages = array(
        'email.required' => 'Preencha o seu email',
        'email.email'    => 'Preencha um email válido',
    );

    /**
     * Fillable fields
     */
    public $fillable = array(
        'id',
        'name',
        'email',
        'gender',
        'born_date',
        'city',
        'state',
        'country',
        'created_at',
        'updated_at',
    );

    public function setEmailAttribute($email)
    {
        $this->attributes['email'] = strtolower($email);
    }

    public function setGenderAttribute($value)
    {
        $accepted = array('m', 'f');

        if (in_array($value, $accepted)) {
            $this->attributes['gender'] = $value;
        }
    }

    public function setBornDateAttribute($value)
    {
        if (! $this->attributes['born_date'] = DateTime::createFromFormat('d/m/Y', $value)) {
            $this->attributes['born_date'] = null;
        }
    }

    /**
     * Setando a cidade
     */
    public function setCityAttribute($value)
    {
        if ($value != '') {
            $this->attributes['city'] = $value;
        }
    }

    public function setStateAttribute($value)
    {
        if ($value != '') {
            $this->attributes['state'] = $value;
        }
    }

    public function setCountryAttribute($value)
    {
        if ($value != '') {
            $this->attributes['country'] = $value;
        }
    }

    public function saveFromArray($fields)
    {
        $this->fill($fields);

        if (! $this->validate()) {
            return false;
        }

        return $this->save();
    }
}
