<?php namespace EscapeWork\Manager\Subscribers\Repositories\Subscriber;

use EscapeWork\Manager\Repositories\BaseEloquentRepository;
use EscapeWork\Manager\Subscribers\Models\Subscriber;
use DateTime;

class EloquentSubscriberRepository extends BaseEloquentRepository implements SubscriberRepository
{

    /**
     * Valid orderBy fields
     */
    protected $orderByFields = array(
        'id',
        'name',
        'email',
    );

    public function __construct(Subscriber $subscriber)
    {
        $this->model = $subscriber;
    }

    public function filterAndPaginate(array $params = array())
    {
        $query = $this->model->newQuery();

        if (isset($params['name']) && $params['name'] != '') {
            $query->where('name', 'like', '%'.$params['name'].'%');
        }

        if (isset($params['email']) && $params['email'] != '') {
            $query->where('email', 'like', '%'.$params['email'].'%');
        }

        $this->configureOrderBy($query, $params);

        return $query->paginate();
    }

    public function save($options = array())
    {
        if (! $this->model->exists && $subscriber = $this->model->where('email', '=', $this->model->email)->first()) {
            $this->model->exists = true;
            $this->model->id     = $subscriber->id;
        }

        return $this->model->save($options);
    }

    public function getNewerSubscribers()
    {
        $yesterday = new DateTime();
        $yesterday->modify('-1 day');
        $date      = $yesterday->format('Y-m-d \0\0:\0\0:\0\0');

        return $this->model
                    ->where('created_at', '>=', $date)
                    ->orWhere('updated_at', '>=', $date)
                    ->get();
    }
}
